
# Slot: iso abbreviation


Optional value, if used locally as a convenience, is set to the iso abbreviation of the 'published in' parent.

URI: [biolink:article_iso_abbreviation](https://w3id.org/biolink/vocab/article_iso_abbreviation)


## Domain and Range

[Article](Article.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [iso abbreviation](iso_abbreviation.md)

## Children


## Used by

 * [Article](Article.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | WIKIDATA_PROPERTY:P1160 |

